@@ -1,7 +1,7 @@
 import dataclasses
 import logging
 import irisml.core
-from typing import Union, List
+from typing import Union, List, Optional
 
 logger = logging.getLogger(__name__)
 
@@ -21,7 +21,7 @@ class Task(irisml.core.TaskBase):
     class Inputs:
         conditions: List[bool]
         vals: List[Union[float, int, str]]
-        default: Union[float, int, str] = None
+        default: Optional[Union[float, int, str]] = None
 
     @dataclasses.dataclass
     class Outputs:
@@ -32,8 +32,10 @@ class Task(irisml.core.TaskBase):
 
         for i, cond in enumerate(inputs.conditions):
             if cond:
+                logger.info(f'{i}th condition is True and got picked.')
                 return self.Outputs(inputs.vals[i])
 
+        logger.info(f'None of conditions is True: default {inputs.default} returned.')
         return self.Outputs(inputs.default)
 
     def dry_run(self, inputs):
